@@ -11,6 +11,7 @@ my $dict = {pinyin => {},
 store($dict, "Mandarin.dict");
 
 use eGuideDog::Dict::Mandarin;
-$dict=eGuideDog::Dict::Mandarin->new();
-$dict->update_dict();
+my $dict = {};
+bless $dict, 'eGuideDog::Dict::Mandarin';
+eGuideDog::Dict::Mandarin::update_dict($dict);
 
